/*!
FullCalendar Scheduler v6.0.0-beta.1
Docs & License: https://fullcalendar.io/scheduler
(c) 2022 Adam Shaw
*/
var FullCalendarPremiumCommon = (function (exports, common) {
    'use strict';

    const RELEASE_DATE = '2022-08-03'; // for Scheduler
    const UPGRADE_WINDOW = 365 + 7; // days. 1 week leeway, for tz shift reasons too
    const INVALID_LICENSE_URL = 'http://fullcalendar.io/docs/schedulerLicenseKey#invalid';
    const OUTDATED_LICENSE_URL = 'http://fullcalendar.io/docs/schedulerLicenseKey#outdated';
    const PRESET_LICENSE_KEYS = [
        'GPL-My-Project-Is-Open-Source',
        'CC-Attribution-NonCommercial-NoDerivatives',
    ];
    const CSS = {
        position: 'absolute',
        zIndex: 99999,
        bottom: '1px',
        left: '1px',
        background: '#eee',
        borderColor: '#ddd',
        borderStyle: 'solid',
        borderWidth: '1px 1px 0 0',
        padding: '2px 4px',
        fontSize: '12px',
        borderTopRightRadius: '3px',
    };
    function buildLicenseWarning(context) {
        let key = context.options.schedulerLicenseKey;
        let currentUrl = typeof window !== 'undefined' ? window.location.href : '';
        if (!isImmuneUrl(currentUrl)) {
            let status = processLicenseKey(key);
            if (status !== 'valid') {
                return (common.createElement("div", { className: "fc-license-message", style: CSS }, (status === 'outdated') ? (common.createElement(common.Fragment, null,
                    'Your license key is too old to work with this version. ',
                    common.createElement("a", { href: OUTDATED_LICENSE_URL }, "More Info"))) : (common.createElement(common.Fragment, null,
                    'Your license key is invalid. ',
                    common.createElement("a", { href: INVALID_LICENSE_URL }, "More Info")))));
            }
        }
        return null;
    }
    /*
    This decryption is not meant to be bulletproof. Just a way to remind about an upgrade.
    */
    function processLicenseKey(key) {
        if (PRESET_LICENSE_KEYS.indexOf(key) !== -1) {
            return 'valid';
        }
        const parts = (key || '').match(/^(\d+)-fcs-(\d+)$/);
        if (parts && (parts[1].length === 10)) {
            const purchaseDate = new Date(parseInt(parts[2], 10) * 1000);
            const releaseDate = new Date(common.config.mockSchedulerReleaseDate || RELEASE_DATE);
            if (common.isValidDate(releaseDate)) { // token won't be replaced in dev mode
                const minPurchaseDate = common.addDays(releaseDate, -UPGRADE_WINDOW);
                if (minPurchaseDate < purchaseDate) {
                    return 'valid';
                }
                return 'outdated';
            }
        }
        return 'invalid';
    }
    function isImmuneUrl(url) {
        return /\w+:\/\/fullcalendar\.io\/|\/examples\/[\w-]+\.html$/.test(url);
    }

    const OPTION_REFINERS = {
        schedulerLicenseKey: String,
    };

    var plugin = common.createPlugin({
        optionRefiners: OPTION_REFINERS,
        viewContainerAppends: [buildLicenseWarning],
    });

    common.globalPlugins.push(plugin);

    exports.default = plugin;

    Object.defineProperty(exports, '__esModule', { value: true });

    return exports;

}({}, FullCalendar));
